@@ -14,7 +14,7 @@ use Scalar::Util;
 use Module::Pluggable ( search_path => 'Template::Benchmark::Engines',
                         sub_name    => 'engine_plugins' );
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 my @valid_features = qw/
     literal_text
@@ -429,6 +429,9 @@ sub new
         }
 
         $template = $template x $options->{ template_repeats };
+        #  Allow the plugin a chance to rewrite the repeated sections,
+        #  ie: some engines require unique loop names/labels.
+        $template = $engine->preprocess_template( $template );
 
         $template_filename =
             File::Spec->catfile( $template_dir, $leaf . '.txt' );
@@ -555,6 +558,7 @@ sub benchmark
                 delete $self->{ benchmark_functions }->{ $type }->{ $tag };
                 next;
             }
+            $output = ${$output} if $output and ref( $output );
             #  [rt #59247] Normalize newline endings, some template engines
             #  produce UNIX and some Windows line-endings when on Windows.
             $output =~ s/\r//g if $output;
@@ -755,7 +759,7 @@ Template::Benchmark - Pluggable benchmarker to cross-compare template systems.
 
     my $bench = Template::Benchmark->new(
         duration            => 5,
-        repeats             => 1,
+        template_repeats    => 1,
         array_loop          => 1,
         shared_memory_cache => 0,
         );
