@@ -11,7 +11,7 @@ use HTML::Template;
 use HTML::Template::Expr;
 use HTML::Template::Pro;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 our %feature_syntaxes = (
     literal_text              =>
@@ -98,7 +98,7 @@ sub benchmark_functions_for_uncached_string
                 $t->param( $_[ 1 ] );
                 $t->param( $_[ 2 ] );
                 my $out = $t->output();
-                $out;
+                \$out;
             },
         } );
 }
@@ -123,7 +123,7 @@ sub benchmark_functions_for_uncached_disk
                 $t->param( $_[ 1 ] );
                 $t->param( $_[ 2 ] );
                 my $out = $t->output();
-                $out;
+                \$out;
             },
         } );
 }
