@@ -7,7 +7,7 @@ use base qw/Template::Benchmark::Engine/;
 
 use Template::Alloy;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 our %feature_syntaxes = (
     literal_text              =>
@@ -97,7 +97,7 @@ sub benchmark_functions_for_uncached_string
                     );
                 $t->param( $_[ 1 ] );
                 $t->param( $_[ 2 ] );
-                $t->output();
+                \$t->output();
             },
         } );
 }
@@ -131,7 +131,7 @@ sub benchmark_functions_for_disk_cache
                     );
                 $t->param( $_[ 1 ] );
                 $t->param( $_[ 2 ] );
-                $t->output();
+                \$t->output();
             },
         } );
 }
@@ -161,7 +161,7 @@ sub benchmark_functions_for_shared_memory_cache
                     );
                 $t->param( $_[ 1 ] );
                 $t->param( $_[ 2 ] );
-                $t->output();
+                \$t->output();
             },
         } );
 }
@@ -187,7 +187,7 @@ sub benchmark_functions_for_memory_cache
                     );
                 $t->param( $_[ 1 ] );
                 $t->param( $_[ 2 ] );
-                $t->output();
+                \$t->output();
             },
         } );
 }
